@@ -1,7 +1,6 @@
-from aiopg import Cursor, Connection
 from psycopg2.sql import SQL
 
-from hub import Hub
+from aiogram_metrics.hub import Hub
 
 
 class MessageType:
@@ -25,7 +24,6 @@ async def init_table():
     async with Hub.connection_pool.acquire() as conn:
         async with conn.cursor() as cur:
             await cur.execute(query)
-            conn: Connection
 
             if not conn.notices:
                 Hub.logger.debug(f'Table {Hub.table_name} successfully created!')
